---
title: How to Remember U.S. State Abbreviations
tags: post
layout: post
date: 2022-04-17
permalink: remember-us-state-abbreviations/
---

I like maps and recently learnt the U.S. state abbreviations by heart for no particular reason.
The abbreviations are highly irregular, both for logical reasons and historical reasons, which makes them especially
hard to learn.
I created a set of rules that may help you remember the abbreviations more easily.
The rules are very straightforward, as my goal was to avoid creating rules that have multiple levels of exceptions.
<!-- excerpt -->

There are eight rules divided into three categories.
Firstly, states that consist of two words have one very simple rule.
Secondly, states that start with M, A, I, or N have a complicated rule each.
Finally, the remaining states have a very simple rule depending on the first letter.

1. **Two-word states**  
   If the state consists of two words, the abbreviation is the **first letter of each word**.
   | State                  | Abbreviation |
   |------------------------|--------------|
   | New Hampshire          | NH           |
   | New Jersey             | NJ           |
   | New Mexico             | NM           |
   | New York               | NY           |
   | North Carolina         | NC           |
   | North Dakota           | ND           |
   | Rhode Island           | RI           |
   | South Carolina         | SC           |
   | South Dakota           | SD           |
   | West Virginia          | WV           |
   | _District of Columbia_ | _DC_         |
   | _Puerto Rico_          | _PR_         |
2. **MAIN states**  
   The following four rules describe states that start with M, A, I, or N.
   These are the most frequent first letters, and are the most complicated to remember.

   1. **M states**  
      These are by far the hardest to remember, because there is no real structure to them.
      But we can sub-divide this into three categories:
      starting with MA, starting with MI, and starting with MO.
      Once you figure that out, you can use mnemonics to distinguish them from each other.
      | State         | Abbreviation | Mnemonic                                        |
      |---------------|--------------|-------------------------------------------------|
      | Maine         | ME           | All other options are taken                     |
      | Maryland      | MD           | Medical Doctors live in Maryland                |
      | Massachusetts | MA           | Easternmost MA state gets simplest abbreviation |
      | Michigan      | MI           | Easternmost MI state gets simplest abbreviation |
      | Minnesota     | MN           | All other options are taken                     |
      | Mississippi   | MS           | Many S's                                        |
      | Missouri      | MO           | Miss Ouri                                       |
      | Montana       | MT           | MounTain                                        |
   2. **A states**  
      We actually have two sets of two here: two states starting with AL, and two starting with AR.
      I've come up with a few mnemonics to help you distinguish them.
      | State         | Abbreviation | Mnemonic                             |
      |---------------|--------------|--------------------------------------|
      | Alabama       | AL           | Al lives in Alabama                  |
      | Alaska        | AK           | Alaskans like Kalashnikovs?          |
      | Arizona       | AZ           | Z is unique, so use it when you can! |
      | Arkansas      | AR           | Pirate says "Arr"                    |
   3. **I states**  
      Use the **first two letters, unless it's Iowa**.
      As a mnemonic, try "I owes an A".
      | State         | Abbreviation |
      |---------------|--------------|
      | Idaho         | ID           |
      | Illinois      | IL           |
      | Indiana       | IN           |
      | Iowa          | IA           |
   4. **N states**  
      This one requires a bit of deduction.
      Both Nebraska and Nevada could use NE, but if we give NE to Nevada then Nebraska becomes NB, and no abbreviation
      ever uses the letter B.
      Therefore, we **must give NE to Nebraska**.
      | State         | Abbreviation |
      |---------------|--------------|
      | Nebraska      | NE           |
      | Nevada        | NV           |
3. **Simple rules**  
   All remaining states are very regular, and we can determine the abbreviation by looking at the first letter.
   1. **Texassee**  
      If we're talking about Tennessee or Texas, the abbreviation is the **first and third letter**.
      | State     | Abbreviation |
      |-----------|--------------|
      | Tennessee | TN           |
      | Texas     | TX           |
   2. **WOODRUFF states**  
      If the name starts with a letter of WOODRUFF, the abbreviation is the **first two letters**.  
      Remember that Rhode Island is already covered by the very first rule!
      | State      | Abbreviation |
      |------------|--------------|
      | Delaware   | DE           |
      | Florida    | FL           |
      | Ohio       | OH           |
      | Oklahoma   | OK           |
      | Oregon     | OR           |
      | Utah       | UT           |
      | Washington | WA           |
      | Wisconsin  | WI           |
      | Wyoming    | WY           |
   3. **HYPERCLEVER GEEK states**  
      If the name starts with a letter of HYPERCLEVER GEEK, the abbreviation is the **first and last letter**.  
      Alternatively, remember that these are the states that start with a consonant, but are not covered by MAIN,
      WOODRUFF, or Texassee.
      Either way, remember that Rhode Island is already covered by the very first rule.
      | State        | Abbreviation |
      |--------------|--------------|
      | California   | CA           |
      | Colorado     | CO           |
      | Connecticut  | CT           |
      | Georgia      | GA           |
      | Hawaii       | HI           |
      | Kansas       | KS           |
      | Kentucky     | KY           |
      | Louisiana    | LA           |
      | Pennsylvania | PA           |
      | Vermont      | VT           |
      | Virginia     | VA           |

And that wraps up the list of rules!
Good luck with learning!
